@@ -1,6 +1,6 @@
 #
 # Explode.pm
-# Last Modification: Fri Jun 20 14:38:49 WEST 2003
+# Last Modification: Tue Aug  5 15:57:05 WEST 2003
 #
 # Copyright (c) 2003 Henrique Dias <hdias@aesbuc.pt>. All rights reserved.
 # This module is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@ use vars qw($VERSION @ISA @EXPORT);
 
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw(&rfc822_base64 &rfc822_qprint);
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 use constant BUFFSIZE => 64;
 
@@ -32,11 +32,11 @@ my %h_hash = (
 
 my @patterns = (
 	'^([^= ]+) *=[ \"]*([^\"]+)',
-	'^(\w[\w\-]*): *([^\x0d\x0a\x09\f]*)[\x0d\x0a\x09\f]+',
+	'^(\w[\w\-]*):[\x20\x09]*([^\x0d\x0a\f]*)[\x0d\x0a\f]+',
 	'^[\x0a\x0d]+$',
 	'^begin\s*(\d\d\d)\s*(\S+)',
 	'^From +[^ ]+ +[a-zA-Z]{3} [a-zA-Z]{3} [ \d]\d \d\d:\d\d:\d\d \d{4}( [\+\-]\d\d\d\d)?[\x0a\x0d]+',
-	'^[ \t]+(?=.*\w+)'
+	'^[\x20\x09]+(?=.*\w+)'
 );
 
 my %content_type = (
@@ -80,7 +80,7 @@ sub parse {
 	}
 	if(!(-d $self->{output_dir}) && $self->{mkdir}) {
 		mkdir($self->{output_dir}, $self->{mkdir}) or
-			die("MIME::Explode: Failed to create directory \"" . $self->{output_dir} . "\" $!");
+			die(join("", "MIME::Explode: Failed to create directory \"", $self->{output_dir}, "\" $!"));
 	}
 	my $last = &_parse(\@_, 1, 0, "0", "", $args, {}, \%headers);
 	$self->{nmsgs} = ($last->[0]) ? (split(/\./, $last->[0]))[0] + 1 : 0;
@@ -126,7 +126,7 @@ sub _parse {
 					next;
 				}
 				if(exists($h_hash{$key}) && exists($_[0]->{$tree}->{$key}->{value})) {
-					my @params = split(/ *; */o, $_[0]->{$tree}->{$key}->{value});
+					my @params = split(/[\x20\x09]*;[\x20\x09]*/o, $_[0]->{$tree}->{$key}->{value});
 					$_[0]->{$tree}->{$key}->{value} = shift(@params) || "";
 					map { /$patterns[0]/o and $_[0]->{$tree}->{$key}->{lc($1)} = $2; } @params;
 				} elsif($key eq "subject" && $args->{decode_subject}) {
